pub struct HttpRequestMatcher<B> { /* private fields */ }Expand description
Matches CanisterHttpRequests whose body can be deserialized and matched by B.
The type parameter B determines what kind of body is matched:
SingleJsonRpcMatcherfor single JSON-RPC requests (seeJsonRpcRequestMatcher)Vec<SingleJsonRpcMatcher>for batch JSON-RPC requests (seeBatchJsonRpcRequestMatcher)
Implementations
Sourceimpl<B> HttpRequestMatcher<B>
impl<B> HttpRequestMatcher<B>
Sourcepub fn with_url(self, url: &str) -> Self
pub fn with_url(self, url: &str) -> Self
Mutates the matcher to match only requests with the given URL.
Sourcepub fn with_host(self, host: &str) -> Self
pub fn with_host(self, host: &str) -> Self
Mutates the matcher to match only requests whose URL has the given host.
Sourcepub fn with_request_headers(
self,
headers: Vec<(impl ToString, impl ToString)>,
) -> Self
pub fn with_request_headers( self, headers: Vec<(impl ToString, impl ToString)>, ) -> Self
Mutates the matcher to match requests with the given HTTP headers.
Sourcepub fn with_max_response_bytes(self, max_response_bytes: impl Into<u64>) -> Self
pub fn with_max_response_bytes(self, max_response_bytes: impl Into<u64>) -> Self
Mutates the matcher to match requests with the given max_response_bytes.
Sourceimpl HttpRequestMatcher<SingleJsonRpcMatcher>
impl HttpRequestMatcher<SingleJsonRpcMatcher>
Sourcepub fn with_method(method: impl Into<String>) -> Self
pub fn with_method(method: impl Into<String>) -> Self
Create a JsonRpcRequestMatcher that matches only JSON-RPC requests with the given method.
Sourcepub fn with_id(self, id: u64) -> Self
pub fn with_id(self, id: u64) -> Self
Mutates the JsonRpcRequestMatcher to match only requests whose JSON-RPC request ID is a
ConstantSizeId with the given value.
Sourcepub fn with_raw_id(self, id: Id) -> Self
pub fn with_raw_id(self, id: Id) -> Self
Mutates the JsonRpcRequestMatcher to match only requests whose JSON-RPC request ID is an
Id with the given value.
Sourcepub fn with_params(self, params: impl Into<Value>) -> Self
pub fn with_params(self, params: impl Into<Value>) -> Self
Mutates the JsonRpcRequestMatcher to match only requests with the given JSON-RPC request
parameters.
Sourceimpl HttpRequestMatcher<Vec<SingleJsonRpcMatcher>>
impl HttpRequestMatcher<Vec<SingleJsonRpcMatcher>>
Sourcepub fn batch(matchers: Vec<SingleJsonRpcMatcher>) -> Self
pub fn batch(matchers: Vec<SingleJsonRpcMatcher>) -> Self
Create a BatchJsonRpcRequestMatcher that matches a batch JSON-RPC request
containing exactly the given individual matchers, matched pairwise in order.